==> json-joy-2.17.0.tgz: package/esm/json-crdt-patch/Draft.js <==
import { LogicalVectorClock, LogicalTimestamp } from './clock';
import { PatchBuilder } from './PatchBuilder';
import { Patch } from './Patch';
import { DeleteOperation } from './operations/DeleteOperation';
import { InsertArrayElementsOperation } from './operations/InsertArrayElementsOperation';
import { InsertStringSubstringOperation } from './operations/InsertStringSubstringOperation';
import { MakeArrayOperation } from './operations/MakeArrayOperation';
import { MakeNumberOperation } from './operations/MakeNumberOperation';
import { MakeObjectOperation } from './operations/MakeObjectOperation';
import { MakeStringOperation } from './operations/MakeStringOperation';
import { SetNumberOperation } from './operations/SetNumberOperation';
import { SetObjectKeysOperation } from './operations/SetObjectKeysOperation';
import { SetRootOperation } from './operations/SetRootOperation';
import { NoopOperation } from './operations/NoopOperation';
import { MakeConstantOperation } from './operations/MakeConstantOperation';
import { MakeValueOperation } from './operations/MakeValueOperation';
export class Draft {
    constructor() {
        this.builder = new PatchBuilder(new LogicalVectorClock(-1, 0));
    }
    patch(clock) {
        const patch = new Patch();
        const ops = this.builder.patch.ops;
        const ts = (id) => id.getSessionId() !== -1 ? id : new LogicalTimestamp(clock.getSessionId(), clock.time + id.time);
        for (const op of ops) {
            if (op instanceof DeleteOperation)
                patch.ops.push(new DeleteOperation(ts(op.id), ts(op.obj), ts(op.after), op.length));
            else if (op instanceof InsertArrayElementsOperation)
                patch.ops.push(new InsertArrayElementsOperation(ts(op.id), ts(op.arr), ts(op.after), op.elements.map(ts)));
            else if (op instanceof InsertStringSubstringOperation)
                patch.ops.push(new InsertStringSubstringOperation(ts(op.id), ts(op.obj), ts(op.after), op.substring));
            else if (op instanceof MakeArrayOperation)
                patch.ops.push(new MakeArrayOperation(ts(op.id)));
            else if (op instanceof MakeConstantOperation)
                patch.ops.push(new MakeConstantOperation(ts(op.id), op.value));
            else if (op instanceof MakeValueOperation)
                patch.ops.push(new MakeValueOperation(ts(op.id), op.value));
            else if (op instanceof MakeNumberOperation)
                patch.ops.push(new MakeNumberOperation(ts(op.id)));
            else if (op instanceof MakeObjectOperation)
                patch.ops.push(new MakeObjectOperation(ts(op.id)));
            else if (op instanceof MakeStringOperation)
                patch.ops.push(new MakeStringOperation(ts(op.id)));
            else if (op instanceof SetNumberOperation)
                patch.ops.push(new SetNumberOperation(ts(op.id), ts(op.num), op.value));
            else if (op instanceof SetObjectKeysOperation)
                patch.ops.push(new SetObjectKeysOperation(ts(op.id), ts(op.object), op.tuples.map(([key, value]) => [key, ts(value)])));
            else if (op instanceof SetRootOperation)
                patch.ops.push(new SetRootOperation(ts(op.id), ts(op.value)));
            else if (op instanceof NoopOperation)
                patch.ops.push(new NoopOperation(ts(op.id), op.length));
        }
        return patch;
    }
}

==> json-joy-7.1.0.tgz: package/esm/json-crdt-patch/Draft.js <==
import { LogicalVectorClock, LogicalTimestamp } from './clock';
import { PatchBuilder } from './PatchBuilder';
import { Patch } from './Patch';
import { DeleteOperation } from './operations/DeleteOperation';
import { InsertArrayElementsOperation } from './operations/InsertArrayElementsOperation';
import { InsertStringSubstringOperation } from './operations/InsertStringSubstringOperation';
import { MakeArrayOperation } from './operations/MakeArrayOperation';
import { MakeNumberOperation } from './operations/MakeNumberOperation';
import { MakeObjectOperation } from './operations/MakeObjectOperation';
import { MakeStringOperation } from './operations/MakeStringOperation';
import { SetNumberOperation } from './operations/SetNumberOperation';
import { SetObjectKeysOperation } from './operations/SetObjectKeysOperation';
import { SetRootOperation } from './operations/SetRootOperation';
import { NoopOperation } from './operations/NoopOperation';
import { MakeConstantOperation } from './operations/MakeConstantOperation';
import { MakeValueOperation } from './operations/MakeValueOperation';
export class Draft {
    builder = new PatchBuilder(new LogicalVectorClock(-1, 0));
    patch(clock) {
        const patch = new Patch();
        const ops = this.builder.patch.ops;
        const ts = (id) => id.getSessionId() !== -1 ? id : new LogicalTimestamp(clock.getSessionId(), clock.time + id.time);
        for (const op of ops) {
            if (op instanceof DeleteOperation)
                patch.ops.push(new DeleteOperation(ts(op.id), ts(op.obj), ts(op.after), op.length));
            else if (op instanceof InsertArrayElementsOperation)
                patch.ops.push(new InsertArrayElementsOperation(ts(op.id), ts(op.arr), ts(op.after), op.elements.map(ts)));
            else if (op instanceof InsertStringSubstringOperation)
                patch.ops.push(new InsertStringSubstringOperation(ts(op.id), ts(op.obj), ts(op.after), op.substring));
            else if (op instanceof MakeArrayOperation)
                patch.ops.push(new MakeArrayOperation(ts(op.id)));
            else if (op instanceof MakeConstantOperation)
                patch.ops.push(new MakeConstantOperation(ts(op.id), op.value));
            else if (op instanceof MakeValueOperation)
                patch.ops.push(new MakeValueOperation(ts(op.id), op.value));
            else if (op instanceof MakeNumberOperation)
                patch.ops.push(new MakeNumberOperation(ts(op.id)));
            else if (op instanceof MakeObjectOperation)
                patch.ops.push(new MakeObjectOperation(ts(op.id)));
            else if (op instanceof MakeStringOperation)
                patch.ops.push(new MakeStringOperation(ts(op.id)));
            else if (op instanceof SetNumberOperation)
                patch.ops.push(new SetNumberOperation(ts(op.id), ts(op.num), op.value));
            else if (op instanceof SetObjectKeysOperation)
                patch.ops.push(new SetObjectKeysOperation(ts(op.id), ts(op.object), op.tuples.map(([key, value]) => [key, ts(value)])));
            else if (op instanceof SetRootOperation)
                patch.ops.push(new SetRootOperation(ts(op.id), ts(op.value)));
            else if (op instanceof NoopOperation)
                patch.ops.push(new NoopOperation(ts(op.id), op.length));
        }
        return patch;
    }
}
